Alert class

An alert affecting a customer.

Constructors

Alert({String? alertId, String? createTime, String? customerId, Map<String, Object?>? data, bool? deleted, String? endTime, String? etag, AlertMetadata? metadata, String? securityInvestigationToolLink, String? source, String? startTime, String? type, String? updateTime})
Alert.fromJson(Map json_)

Properties

alertId ↔ String?
The unique identifier for the alert.
getter/setter pair
createTime ↔ String?
The time this alert was created.
getter/setter pair
customerId ↔ String?
The unique identifier of the Google Workspace account of the customer.
getter/setter pair
data ↔ Map<String, Object?>?
The data associated with this alert, for example google.apps.alertcenter.type.DeviceCompromised.
getter/setter pair
deleted ↔ bool?
True if this alert is marked for deletion.
getter/setter pair
endTime ↔ String?
The time the event that caused this alert ceased being active.
getter/setter pair
etag ↔ String?
etag is used for optimistic concurrency control as a way to help prevent simultaneous updates of an alert from overwriting each other.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
metadata ↔ AlertMetadata?
The metadata associated with this alert.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
An optional Security Investigation Tool query for this alert.
getter/setter pair
source ↔ String?
A unique identifier for the system that reported the alert.
getter/setter pair
startTime ↔ String?
The time the event that caused this alert was started or detected.
getter/setter pair
type ↔ String?
The type of the alert.
getter/setter pair
updateTime ↔ String?
The time this alert was last updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited