AlertFeedback class

A customer feedback about an alert.

Constructors

AlertFeedback({String? alertId, String? createTime, String? customerId, String? email, String? feedbackId, String? type})
AlertFeedback.fromJson(Map json_)

Properties

alertId ↔ String?
The alert identifier.
getter/setter pair
createTime ↔ String?
The time this feedback was created.
getter/setter pair
customerId ↔ String?
The unique identifier of the Google Workspace account of the customer.
getter/setter pair
email ↔ String?
The email of the user that provided the feedback.
getter/setter pair
feedbackId ↔ String?
The unique identifier for the feedback.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
The type of the feedback.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited