GoogleAnalyticsAdminV1betaAccessQuota class

Current state of all quotas for this Analytics property.

If any quota for a property is exhausted, all requests to that property will return Resource Exhausted errors.

Properties

concurrentRequests ↔ GoogleAnalyticsAdminV1betaAccessQuotaStatus?
Properties can use up to 50 concurrent requests.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serverErrorsPerProjectPerHour ↔ GoogleAnalyticsAdminV1betaAccessQuotaStatus?
Properties and cloud project pairs can have up to 50 server errors per hour.
getter/setter pair
tokensPerDay ↔ GoogleAnalyticsAdminV1betaAccessQuotaStatus?
Properties can use 250,000 tokens per day.
getter/setter pair
tokensPerHour ↔ GoogleAnalyticsAdminV1betaAccessQuotaStatus?
Properties can use 50,000 tokens per hour.
getter/setter pair
tokensPerProjectPerHour ↔ GoogleAnalyticsAdminV1betaAccessQuotaStatus?
Properties can use up to 25% of their tokens per project per hour.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited