GoogleAnalyticsAdminV1betaChangeHistoryChange class

A description of a change to a single Google Analytics resource.

Properties

action ↔ String?
The type of action that changed this resource. Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
resource ↔ String?
Resource name of the resource whose changes are described by this entry.
getter/setter pair
resourceAfterChange ↔ GoogleAnalyticsAdminV1betaChangeHistoryChangeChangeHistoryResource?
Resource contents from after the change was made.
getter/setter pair
resourceBeforeChange ↔ GoogleAnalyticsAdminV1betaChangeHistoryChangeChangeHistoryResource?
Resource contents from before the change was made.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited