name property
The name of the dimension.
See the
API Dimensions
for the list of dimension names. If dimensionExpression is specified,
name can be any string that you would like within the allowed character
set. For example if a dimensionExpression concatenates country and
city, you could call that dimension countryAndCity. Dimension names
that you choose must match the regular expression "^[a-zA-Z0-9_]$".
Dimensions are referenced by name in dimensionFilter, orderBys,
dimensionExpression, and pivots.
Implementation
core.String? name;