ErrorGroupStats class

Data extracted for a specific group based on certain filter criteria, such as a given time period and/or service filter.

Constructors

ErrorGroupStats({List<ServiceContext>? affectedServices, String? affectedUsersCount, String? count, String? firstSeenTime, ErrorGroup? group, String? lastSeenTime, int? numAffectedServices, ErrorEvent? representative, List<TimedCount>? timedCounts})
ErrorGroupStats.fromJson(Map json_)

Properties

affectedServices ↔ List<ServiceContext>?
Service contexts with a non-zero error count for the given filter criteria.
getter/setter pair
affectedUsersCount ↔ String?
Approximate number of affected users in the given group that match the filter criteria.
getter/setter pair
count ↔ String?
Approximate total number of events in the given group that match the filter criteria.
getter/setter pair
firstSeenTime ↔ String?
Approximate first occurrence that was ever seen for this group and which matches the given filter criteria, ignoring the time_range that was specified in the request.
getter/setter pair
group ↔ ErrorGroup?
Group data that is independent of the filter criteria.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lastSeenTime ↔ String?
Approximate last occurrence that was ever seen for this group and which matches the given filter criteria, ignoring the time_range that was specified in the request.
getter/setter pair
numAffectedServices ↔ int?
The total number of services with a non-zero error count for the given filter criteria.
getter/setter pair
representative ↔ ErrorEvent?
An arbitrary event that is chosen as representative for the whole group.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timedCounts ↔ List<TimedCount>?
Approximate number of occurrences over time.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited