HttpRequestContext class

HTTP request data that is related to a reported error.

This data should be provided by the application when reporting an error, unless the error report has been generated automatically from Google App Engine logs.

Constructors

HttpRequestContext({String? method, String? referrer, String? remoteIp, int? responseStatusCode, String? url, String? userAgent})
HttpRequestContext.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
method ↔ String?
The type of HTTP request, such as GET, POST, etc.
getter/setter pair
referrer ↔ String?
The referrer information that is provided with the request.
getter/setter pair
remoteIp ↔ String?
The IP address from which the request originated.
getter/setter pair
responseStatusCode ↔ int?
The HTTP response status code for the request.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url ↔ String?
The URL of the request.
getter/setter pair
userAgent ↔ String?
The user agent information that is provided with the request.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited