ServiceContext class

Describes a running service that sends errors.

Its version changes over time and multiple versions can run in parallel.

Constructors

ServiceContext({String? resourceType, String? service, String? version})
ServiceContext.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
resourceType ↔ String?
Type of the MonitoredResource.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
service ↔ String?
An identifier of the service, such as the name of the executable, job, or Google App Engine service name.
getter/setter pair
version ↔ String?
Represents the source code version that the developer provided, which could represent a version label or a Git SHA-1 hash, for example.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited