TimedCount class

The number of errors in a given time period.

All numbers are approximate since the error events are sampled before counting them.

Constructors

TimedCount({String? count, String? endTime, String? startTime})
TimedCount.fromJson(Map json_)

Properties

count ↔ String?
Approximate number of occurrences in the given time period.
getter/setter pair
endTime ↔ String?
End of the time period to which count refers (excluded).
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime ↔ String?
Start of the time period to which count refers (included).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited