name property
The name of the scan configuration in the form of
projects/[PROJECT_ID]/scanConfigs/[SCAN_CONFIG_ID].
Output only.
Implementation
core.String? name;
The name of the scan configuration in the form of
projects/[PROJECT_ID]/scanConfigs/[SCAN_CONFIG_ID].
Output only.
core.String? name;