bigqueryTableSpec property
Specification that applies to a BigQuery table.
This is only valid on entries of type TABLE.
Implementation
GoogleCloudDatacatalogV1beta1BigQueryTableSpec? bigqueryTableSpec;
Specification that applies to a BigQuery table.
This is only valid on entries of type TABLE.
GoogleCloudDatacatalogV1beta1BigQueryTableSpec? bigqueryTableSpec;