BigTableIODetails class

Metadata for a Cloud Bigtable connector used by the job.

Constructors

BigTableIODetails({String? instanceId, String? projectId, String? tableId})
BigTableIODetails.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
instanceId ↔ String?
InstanceId accessed in the connection.
getter/setter pair
projectId ↔ String?
ProjectId accessed in the connection.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tableId ↔ String?
TableId accessed in the connection.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited