IntegerGauge class

A metric value representing temporal values of a variable.

Constructors

IntegerGauge({String? timestamp, SplitInt64? value})
IntegerGauge.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp ↔ String?
The time at which this value was measured.
getter/setter pair
value ↔ SplitInt64?
The value of the variable represented by this gauge.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited