PipelineDescription class

A descriptive representation of submitted pipeline as well as the executed form.

This data is provided by the Dataflow service for ease of visualizing the pipeline and interpreting Dataflow provided metrics.

Constructors

PipelineDescription({List<DisplayData>? displayData, List<ExecutionStageSummary>? executionPipelineStage, List<TransformSummary>? originalPipelineTransform, String? stepNamesHash})
PipelineDescription.fromJson(Map json_)

Properties

displayData ↔ List<DisplayData>?
Pipeline level display data.
getter/setter pair
executionPipelineStage ↔ List<ExecutionStageSummary>?
Description of each stage of execution of the pipeline.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
originalPipelineTransform ↔ List<TransformSummary>?
Description of each transform in the pipeline and collections between them.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stepNamesHash ↔ String?
A hash value of the submitted pipeline portable graph step names if exists.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited