ProjectsLocationsJobsStagesResource class

Constructors

ProjectsLocationsJobsStagesResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getExecutionDetails(String projectId, String location, String jobId, String stageId, {String? endTime, int? pageSize, String? pageToken, String? startTime, String? $fields}) → Future<StageExecutionDetails>
Request detailed information about the execution status of a stage of the job.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited