PubsubLocation class

Identifies a pubsub location to use for transferring data into or out of a streaming Dataflow job.

Constructors

PubsubLocation({bool? dropLateData, bool? dynamicDestinations, String? idLabel, String? subscription, String? timestampLabel, String? topic, String? trackingSubscription, bool? withAttributes})
PubsubLocation.fromJson(Map json_)

Properties

dropLateData ↔ bool?
Indicates whether the pipeline allows late-arriving data.
getter/setter pair
dynamicDestinations ↔ bool?
If true, then this location represents dynamic topics.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
idLabel ↔ String?
If set, contains a pubsub label from which to extract record ids.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subscription ↔ String?
A pubsub subscription, in the form of "pubsub.googleapis.com/subscriptions//"
getter/setter pair
timestampLabel ↔ String?
If set, contains a pubsub label from which to extract record timestamps.
getter/setter pair
topic ↔ String?
A pubsub topic, in the form of "pubsub.googleapis.com/topics//"
getter/setter pair
trackingSubscription ↔ String?
If set, specifies the pubsub subscription that will be used for tracking custom time timestamps for watermark estimation.
getter/setter pair
withAttributes ↔ bool?
If true, then the client has requested to get pubsub attributes.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited