Sink class

A sink that records can be encoded and written to.

Constructors

Sink({Map<String, Object?>? codec, Map<String, Object?>? spec})
Sink.fromJson(Map json_)

Properties

codec ↔ Map<String, Object?>?
The codec to use to encode data written to the sink.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spec ↔ Map<String, Object?>?
The sink to write to, plus its parameters.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited