StageExecutionDetails class

Information about the workers and work items within a stage.

Constructors

StageExecutionDetails({String? nextPageToken, List<WorkerDetails>? workers})
StageExecutionDetails.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
If present, this response does not contain all requested tasks.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
workers ↔ List<WorkerDetails>?
Workers that have done work on the stage.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited