TopologyConfig class

Global topology of the streaming Dataflow job, including all computations and their sharded locations.

Constructors

TopologyConfig({List<ComputationTopology>? computations, List<DataDiskAssignment>? dataDiskAssignments, int? forwardingKeyBits, int? persistentStateVersion, Map<String, String>? userStageToComputationNameMap})
TopologyConfig.fromJson(Map json_)

Properties

computations ↔ List<ComputationTopology>?
The computations associated with a streaming Dataflow job.
getter/setter pair
dataDiskAssignments ↔ List<DataDiskAssignment>?
The disks assigned to a streaming Dataflow job.
getter/setter pair
forwardingKeyBits ↔ int?
The size (in bits) of keys that will be assigned to source messages.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
persistentStateVersion ↔ int?
Version number for persistent state.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userStageToComputationNameMap ↔ Map<String, String>?
Maps user stage names to stable computation names.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited