WorkItemDetails class

Information about an individual work item execution.

Constructors

WorkItemDetails({String? attemptId, String? endTime, List<MetricUpdate>? metrics, ProgressTimeseries? progress, String? startTime, String? state, StragglerInfo? stragglerInfo, String? taskId})
WorkItemDetails.fromJson(Map json_)

Properties

attemptId ↔ String?
Attempt ID of this work item
getter/setter pair
endTime ↔ String?
End time of this work item attempt.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
metrics ↔ List<MetricUpdate>?
Metrics for this work item.
getter/setter pair
progress ↔ ProgressTimeseries?
Progress of this work item.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime ↔ String?
Start time of this work item attempt.
getter/setter pair
state ↔ String?
State of this work item. Possible string values are:
getter/setter pair
stragglerInfo ↔ StragglerInfo?
Information about straggler detections for this work item.
getter/setter pair
taskId ↔ String?
Name of this work item.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited