GoogleCloudDatalabelingV1beta1ObjectTrackingConfig class

Config for video object tracking human labeling task.

Properties

annotationSpecSet ↔ String?
Annotation spec set resource name.
getter/setter pair
clipLength ↔ int?
Videos will be cut to smaller clips to make it easier for labelers to work on.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
overlapLength ↔ int?
The overlap length between different video clips.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited