ProjectsResource class

Constructors

ProjectsResource(ApiRequester client)

Properties

annotationSpecSets → ProjectsAnnotationSpecSetsResource
no setter
datasets → ProjectsDatasetsResource
no setter
evaluationJobs → ProjectsEvaluationJobsResource
no setter
evaluations → ProjectsEvaluationsResource
no setter
hashCode → int
The hash code for this object.
no setterinherited
instructions → ProjectsInstructionsResource
no setter
operations → ProjectsOperationsResource
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited