BackfillAllStrategy class

Backfill strategy to automatically backfill the Stream's objects.

Specific objects can be excluded.

Constructors

BackfillAllStrategy({MysqlRdbms? mysqlExcludedObjects, OracleRdbms? oracleExcludedObjects})
BackfillAllStrategy.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
mysqlExcludedObjects ↔ MysqlRdbms?
MySQL data source objects to avoid backfilling.
getter/setter pair
oracleExcludedObjects ↔ OracleRdbms?
Oracle data source objects to avoid backfilling.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited