ConnectionProfile class

Constructors

ConnectionProfile({String? createTime, String? displayName, ForwardSshTunnelConnectivity? forwardSshConnectivity, GcsProfile? gcsProfile, Map<String, String>? labels, MysqlProfile? mysqlProfile, String? name, NoConnectivitySettings? noConnectivity, OracleProfile? oracleProfile, PrivateConnectivity? privateConnectivity, StaticServiceIpConnectivity? staticServiceIpConnectivity, String? updateTime})
ConnectionProfile.fromJson(Map json_)

Properties

createTime ↔ String?
The create time of the resource.
getter/setter pair
displayName ↔ String?
Display name.
getter/setter pair
forwardSshConnectivity ↔ ForwardSshTunnelConnectivity?
Forward SSH tunnel connectivity.
getter/setter pair
gcsProfile ↔ GcsProfile?
Cloud Storage ConnectionProfile configuration.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
Labels.
getter/setter pair
mysqlProfile ↔ MysqlProfile?
MySQL ConnectionProfile configuration.
getter/setter pair
name ↔ String?
The resource's name.
getter/setter pair
noConnectivity ↔ NoConnectivitySettings?
No connectivity option chosen.
getter/setter pair
oracleProfile ↔ OracleProfile?
Oracle ConnectionProfile configuration.
getter/setter pair
privateConnectivity ↔ PrivateConnectivity?
Private connectivity.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
staticServiceIpConnectivity ↔ NoConnectivitySettings?
Static Service IP connectivity.
getter/setter pair
updateTime ↔ String?
The update time of the resource.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited