DestinationConfig class

The configuration of the stream destination.

Constructors

DestinationConfig({String? destinationConnectionProfileName, GcsDestinationConfig? gcsDestinationConfig})
DestinationConfig.fromJson(Map json_)

Properties

destinationConnectionProfileName ↔ String?
Destination connection profile identifier.
getter/setter pair
gcsDestinationConfig ↔ GcsDestinationConfig?
GCS destination configuration.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited