MysqlSourceConfig class

MySQL source configuration

Constructors

MysqlSourceConfig({MysqlRdbms? allowlist, MysqlRdbms? rejectlist})
MysqlSourceConfig.fromJson(Map json_)

Properties

allowlist ↔ MysqlRdbms?
MySQL objects to retrieve from the source.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
rejectlist ↔ MysqlRdbms?
MySQL objects to exclude from the stream.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited