SourceConfig class

The configuration of the stream source.

Constructors

SourceConfig({MysqlSourceConfig? mysqlSourceConfig, OracleSourceConfig? oracleSourceConfig, String? sourceConnectionProfileName})
SourceConfig.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
mysqlSourceConfig ↔ MysqlSourceConfig?
MySQL data source configuration
getter/setter pair
oracleSourceConfig ↔ OracleSourceConfig?
Oracle data source configuration
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceConnectionProfileName ↔ String?
Source connection profile identifier.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited