GoogleFirebaseFcmDataV1beta1AndroidDeliveryData class

Message delivery data for a given date, app, and analytics label combination.

Properties

analyticsLabel ↔ String?
The analytics label associated with the messages sent.
getter/setter pair
appId ↔ String?
The app ID to which the messages were sent.
getter/setter pair
data ↔ GoogleFirebaseFcmDataV1beta1Data?
The data for the specified appId, date, and analyticsLabel.
getter/setter pair
date ↔ GoogleTypeDate?
The date represented by this entry.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited