GoogleFirebaseFcmDataV1beta1Data class

Data detailing messaging delivery

Properties

countMessagesAccepted ↔ String?
Count of messages accepted by FCM intended to Android devices.
getter/setter pair
deliveryPerformancePercents ↔ GoogleFirebaseFcmDataV1beta1DeliveryPerformancePercents?
Additional information about delivery performance for messages that were successfully delivered.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
messageInsightPercents ↔ GoogleFirebaseFcmDataV1beta1MessageInsightPercents?
Additional general insights about message delivery.
getter/setter pair
messageOutcomePercents ↔ GoogleFirebaseFcmDataV1beta1MessageOutcomePercents?
Mutually exclusive breakdown of message delivery outcomes.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited