AndroidApp class

Details of a Firebase App for Android.

Constructors

AndroidApp({String? apiKeyId, String? appId, String? displayName, String? etag, String? expireTime, String? name, String? packageName, String? projectId, List<String>? sha1Hashes, List<String>? sha256Hashes, String? state})
AndroidApp.fromJson(Map json_)

Properties

apiKeyId ↔ String?
The globally unique, Google-assigned identifier (UID) for the Firebase API key associated with the AndroidApp.
getter/setter pair
appId ↔ String?
The globally unique, Firebase-assigned identifier for the AndroidApp.
getter/setter pair
displayName ↔ String?
The user-assigned display name for the AndroidApp.
getter/setter pair
etag ↔ String?
This checksum is computed by the server based on the value of other fields, and it may be sent with update requests to ensure the client has an up-to-date value before proceeding.
getter/setter pair
expireTime ↔ String?
Timestamp of when the App will be considered expired and cannot be undeleted.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The resource name of the AndroidApp, in the format: projects/ PROJECT_IDENTIFIER/androidApps/APP_ID * PROJECT_IDENTIFIER: the parent Project's [ProjectNumber](../projects#FirebaseProject.FIELDS.project_number) (recommended) or its [ProjectId](../projects#FirebaseProject.FIELDS.project_id).
getter/setter pair
packageName ↔ String?
The canonical package name of the Android app as would appear in the Google Play Developer Console.
getter/setter pair
projectId ↔ String?
A user-assigned unique identifier of the parent FirebaseProject for the AndroidApp.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sha1Hashes ↔ List<String>?
The SHA1 certificate hashes for the AndroidApp.
getter/setter pair
sha256Hashes ↔ List<String>?
The SHA256 certificate hashes for the AndroidApp.
getter/setter pair
state ↔ String?
The lifecycle state of the App.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited