portMappings property
A map of containers to host port mappings for this container.
If the container already specifies exposed ports, use the
PUBLISH_EXPOSED_PORTS flag instead. The host port number must be less
than 65536. If it is zero, an unused random port is assigned. To determine
the resulting port number, consult the ContainerStartedEvent in the
operation metadata.
Implementation
core.Map<core.String, core.int>? portMappings;