productEventDetail property
Retail product specific user event metadata.
This field is required for the following event types: * add-to-cart *
add-to-list * category-page-view * checkout-start *
detail-page-view * purchase-complete * refund * remove-from-cart *
remove-from-list * search This field is optional for the following
event types: * page-visit * shopping-cart-page-view - note that
'product_event_detail' should be set for this unless the shopping cart is
empty. This field is not allowed for the following event types: *
home-page-view
Optional.
Implementation
GoogleCloudRecommendationengineV1beta1ProductEventDetail? productEventDetail;