$SasPortalDeployment class

Used by:

  • prod_tt_sasportal:v1alpha1 : SasPortalDeployment
  • sasportal:v1alpha1 : SasPortalDeployment

Constructors

$SasPortalDeployment({String? displayName, List<String>? frns, String? name, List<String>? sasUserIds})
$SasPortalDeployment.fromJson(Map json_)

Properties

displayName ↔ String?
The deployment's display name.
getter/setter pair
frns ↔ List<String>?
The FCC Registration Numbers (FRNs) copied from its direct parent.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Resource name.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sasUserIds ↔ List<String>?
User ID used by the devices belonging to this deployment.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited