$SasPortalDeviceAirInterface class

Used by:

  • prod_tt_sasportal:v1alpha1 : SasPortalDeviceAirInterface
  • sasportal:v1alpha1 : SasPortalDeviceAirInterface

Constructors

$SasPortalDeviceAirInterface({String? radioTechnology, String? supportedSpec})
$SasPortalDeviceAirInterface.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
radioTechnology ↔ String?
Conditional.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportedSpec ↔ String?
This field is related to the radioTechnology and provides the air interface specification that the CBSD is compliant with at the time of registration.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited