$SasPortalGenerateSecretResponse class

Used by:

  • prod_tt_sasportal:v1alpha1 : SasPortalGenerateSecretResponse
  • sasportal:v1alpha1 : SasPortalGenerateSecretResponse

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secret ↔ String?
The secret generated by the string and used by ValidateInstaller.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited