AndroidAppInfo class

Android app information.

Constructors

AndroidAppInfo({String? name, String? packageName, String? versionCode, String? versionName})
AndroidAppInfo.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The name of the app.
getter/setter pair
packageName ↔ String?
The package name of the app.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
versionCode ↔ String?
The internal version code of the app.
getter/setter pair
versionName ↔ String?
The version name of the app.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited