AndroidTest class

An Android mobile test specification.

Constructors

AndroidTest({AndroidAppInfo? androidAppInfo, AndroidInstrumentationTest? androidInstrumentationTest, AndroidRoboTest? androidRoboTest, AndroidTestLoop? androidTestLoop, Duration? testTimeout})
AndroidTest.fromJson(Map json_)

Properties

androidAppInfo ↔ AndroidAppInfo?
Information about the application under test.
getter/setter pair
androidInstrumentationTest ↔ AndroidInstrumentationTest?
An Android instrumentation test.
getter/setter pair
androidRoboTest ↔ AndroidRoboTest?
An Android robo test.
getter/setter pair
androidTestLoop ↔ AndroidTestLoop?
An Android test loop.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
testTimeout ↔ Duration?
Max time a test is allowed to run before it is automatically cancelled.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited