AppStartTime class

Constructors

AppStartTime({Duration? fullyDrawnTime, Duration? initialDisplayTime})
AppStartTime.fromJson(Map json_)

Properties

fullyDrawnTime ↔ Duration?
The time from app start to reaching the developer-reported "fully drawn" time.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
initialDisplayTime ↔ Duration?
The time from app start to the first displayed activity being drawn, as reported in Logcat.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited