Environment class

An Environment represents the set of test runs (Steps) from the parent Execution that are configured with the same set of dimensions (Model, Version, Locale, and Orientation).

Multiple such runs occur particularly because of features like sharding (splitting up a test suite to run in parallel across devices) and reruns (running a test multiple times to check for different outcomes).

Constructors

Environment({Timestamp? completionTime, Timestamp? creationTime, List<EnvironmentDimensionValueEntry>? dimensionValue, String? displayName, String? environmentId, MergedResult? environmentResult, String? executionId, String? historyId, String? projectId, ResultsStorage? resultsStorage, List<ShardSummary>? shardSummaries})
Environment.fromJson(Map json_)

Properties

completionTime ↔ Timestamp?
The time when the Environment status was set to complete.
getter/setter pair
creationTime ↔ Timestamp?
The time when the Environment was created.
getter/setter pair
dimensionValue ↔ List<EnvironmentDimensionValueEntry>?
Dimension values describing the environment.
getter/setter pair
displayName ↔ String?
A short human-readable name to display in the UI.
getter/setter pair
environmentId ↔ String?
An Environment id.
getter/setter pair
environmentResult ↔ MergedResult?
Merged result of the environment.
getter/setter pair
executionId ↔ String?
An Execution id.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
historyId ↔ String?
A History id.
getter/setter pair
projectId ↔ String?
A Project id.
getter/setter pair
resultsStorage ↔ ResultsStorage?
The location where output files are stored in the user bucket.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shardSummaries ↔ List<ShardSummary>?
Summaries of shards.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited