Image class

An image, with a link to the main image and a thumbnail.

Constructors

Image({Status? error, ToolOutputReference? sourceImage, String? stepId, Thumbnail? thumbnail})
Image.fromJson(Map json_)

Properties

error ↔ Status?
An error explaining why the thumbnail could not be rendered.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceImage ↔ ToolOutputReference?
A reference to the full-size, original image.
getter/setter pair
stepId ↔ String?
The step to which the image is attached.
getter/setter pair
thumbnail ↔ Thumbnail?
The thumbnail.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited