ListPerfSamplesResponse class

Constructors

ListPerfSamplesResponse({String? nextPageToken, List<PerfSample>? perfSamples})
ListPerfSamplesResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
Optional, returned if result size exceeds the page size specified in the request (or the default page size, 500, if unspecified).
getter/setter pair
perfSamples ↔ List<PerfSample>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited