ListStepsResponse class

Response message for StepService.List.

Constructors

ListStepsResponse({String? nextPageToken, List<Step>? steps})
ListStepsResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
A continuation token to resume the query at the next item.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
steps ↔ List<Step>?
Steps.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited