MemoryInfo class

Constructors

MemoryInfo({String? memoryCapInKibibyte, String? memoryTotalInKibibyte})
MemoryInfo.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
memoryCapInKibibyte ↔ String?
Maximum memory that can be allocated to the process in KiB
getter/setter pair
memoryTotalInKibibyte ↔ String?
Total memory available on the device in KiB
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited