MultiStep class

Details when multiple steps are run with the same configuration as a group.

Constructors

MultiStep({int? multistepNumber, PrimaryStep? primaryStep, String? primaryStepId})
MultiStep.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
multistepNumber ↔ int?
Unique int given to each step.
getter/setter pair
primaryStep ↔ PrimaryStep?
Present if it is a primary (original) step.
getter/setter pair
primaryStepId ↔ String?
Step Id of the primary (original) step, which might be this step.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited