PerfSample class

Resource representing a single performance measure or data point

Constructors

PerfSample({Timestamp? sampleTime, double? value})
PerfSample.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sampleTime ↔ Timestamp?
Timestamp of collection.
getter/setter pair
value ↔ double?
Value observed
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited