Specification class

The details about how to run the execution.

Constructors

Specification({AndroidTest? androidTest, IosTest? iosTest})
Specification.fromJson(Map json_)

Properties

androidTest ↔ AndroidTest?
An Android mobile test execution specification.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
iosTest ↔ IosTest?
An iOS mobile test execution specification.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited