Step class

A Step represents a single operation performed as part of Execution.

A step can be used to represent the execution of a tool ( for example a test runner execution or an execution of a compiler). Steps can overlap (for instance two steps might have the same start time if some operations are done in parallel). Here is an example, let's consider that we have a continuous build is executing a test runner for each iteration. The workflow would look like: - user creates a Execution with id 1 - user creates a TestExecutionStep with id 100 for Execution 1 - user update TestExecutionStep with id 100 to add a raw xml log + the service parses the xml logs and returns a TestExecutionStep with updated TestResult(s). - user update the status of TestExecutionStep with id 100 to COMPLETE A Step can be updated until its state is set to COMPLETE at which points it becomes immutable.

Constructors

Step({Timestamp? completionTime, Timestamp? creationTime, String? description, Duration? deviceUsageDuration, List<EnvironmentDimensionValueEntry>? dimensionValue, bool? hasImages, List<EnvironmentDimensionValueEntry>? labels, MultiStep? multiStep, String? name, Outcome? outcome, Duration? runDuration, String? state, String? stepId, TestExecutionStep? testExecutionStep, ToolExecutionStep? toolExecutionStep})
Step.fromJson(Map json_)

Properties

completionTime ↔ Timestamp?
The time when the step status was set to complete.
getter/setter pair
creationTime ↔ Timestamp?
The time when the step was created.
getter/setter pair
description ↔ String?
A description of this tool For example: mvn clean package -D skipTests=true - In response: present if set by create/update request - In create/update request: optional
getter/setter pair
deviceUsageDuration ↔ Duration?
How much the device resource is used to perform the test.
getter/setter pair
dimensionValue ↔ List<EnvironmentDimensionValueEntry>?
If the execution containing this step has any dimension_definition set, then this field allows the child to specify the values of the dimensions.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hasImages ↔ bool?
Whether any of the outputs of this step are images whose thumbnails can be fetched with ListThumbnails.
getter/setter pair
labels ↔ List<EnvironmentDimensionValueEntry>?
Arbitrary user-supplied key/value pairs that are associated with the step.
getter/setter pair
multiStep ↔ MultiStep?
Details when multiple steps are run with the same configuration as a group.
getter/setter pair
name ↔ String?
A short human-readable name to display in the UI.
getter/setter pair
outcome ↔ Outcome?
Classification of the result, for example into SUCCESS or FAILURE - In response: present if set by create/update request - In create/update request: optional
getter/setter pair
runDuration ↔ Duration?
How long it took for this step to run.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
The initial state is IN_PROGRESS.
getter/setter pair
stepId ↔ String?
A unique identifier within a Execution for this Step.
getter/setter pair
testExecutionStep ↔ TestExecutionStep?
An execution of a test runner.
getter/setter pair
toolExecutionStep ↔ ToolExecutionStep?
An execution of a tool (used for steps we don't explicitly support).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited