TestExecutionStep class

A step that represents running tests.

It accepts ant-junit xml files which will be parsed into structured test results by the service. Xml file paths are updated in order to append more files, however they can't be deleted. Users can also add test results manually by using the test_result field.

Constructors

TestExecutionStep({List<TestIssue>? testIssues, List<TestSuiteOverview>? testSuiteOverviews, TestTiming? testTiming, ToolExecution? toolExecution})
TestExecutionStep.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
testIssues ↔ List<TestIssue>?
Issues observed during the test execution.
getter/setter pair
testSuiteOverviews ↔ List<TestSuiteOverview>?
List of test suite overview contents.
getter/setter pair
testTiming ↔ TestTiming?
The timing break down of the test execution.
getter/setter pair
toolExecution ↔ ToolExecution?
Represents the execution of the test runner.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited