TestIssue class

An issue detected occurring during a test execution.

Constructors

TestIssue({String? category, String? errorMessage, String? severity, StackTrace? stackTrace, String? type, Any? warning})
TestIssue.fromJson(Map json_)

Properties

category ↔ String?
Category of issue.
getter/setter pair
errorMessage ↔ String?
A brief human-readable message describing the issue.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severity ↔ String?
Severity of issue.
getter/setter pair
stackTrace ↔ StackTrace?
Deprecated in favor of stack trace fields inside specific warnings.
getter/setter pair
type ↔ String?
Type of issue.
getter/setter pair
warning ↔ Any?
Warning message with additional details of the issue.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited