TestSuiteOverview class

A summary of a test suite result either parsed from XML or uploaded directly by a user.

Note: the API related comments are for StepService only. This message is also being used in ExecutionService in a read only mode for the corresponding step.

Constructors

TestSuiteOverview({Duration? elapsedTime, int? errorCount, int? failureCount, int? flakyCount, String? name, int? skippedCount, int? totalCount, FileReference? xmlSource})
TestSuiteOverview.fromJson(Map json_)

Properties

elapsedTime ↔ Duration?
Elapsed time of test suite.
getter/setter pair
errorCount ↔ int?
Number of test cases in error, typically set by the service by parsing the xml_source.
getter/setter pair
failureCount ↔ int?
Number of failed test cases, typically set by the service by parsing the xml_source.
getter/setter pair
flakyCount ↔ int?
Number of flaky test cases, set by the service by rolling up flaky test attempts.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The name of the test suite.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skippedCount ↔ int?
Number of test cases not run, typically set by the service by parsing the xml_source.
getter/setter pair
totalCount ↔ int?
Number of test cases, typically set by the service by parsing the xml_source.
getter/setter pair
xmlSource ↔ FileReference?
If this test suite was parsed from XML, this is the URI where the original XML file is stored.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited