ToolOutputReference class

A reference to a ToolExecution output file.

Constructors

ToolOutputReference({Timestamp? creationTime, FileReference? output, TestCaseReference? testCase})
ToolOutputReference.fromJson(Map json_)

Properties

creationTime ↔ Timestamp?
The creation time of the file.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
output ↔ FileReference?
A FileReference to an output file.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
testCase ↔ TestCaseReference?
The test case to which this output file belongs.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited